Resp3Value

Enum Resp3Value 

pub enum Resp3Value {
Show 15 variants SimpleString(String), SimpleError(String), Number(i64), BlobString(String), Array(Vec<Self>), Null, Boolean(bool), Double(f64), BigNumber(String), BlobError(String), VerbatimString { encoding: String, data: String, }, Map(HashMap<String, Self>), Set(HashSet<Self>), Attribute { attrs: HashMap<String, Self>, data: Box<Self>, }, Push(Vec<Self>),
}
RESP3 protocol data types

Variants



SimpleString(String)

Simple string: +OK\r\n



SimpleError(String)

Simple error: -ERR message\r\n



Number(i64)

Number (integer): :123\r\n



BlobString(String)

Blob string: $5\r\nhello\r\n



Array(Vec<Self>)

Array: *3\r\n$3\r\nfoo\r\n$3\r\nbar\r\n$3\r\nbaz\r\n



Null

Null: _\r\n



Boolean(bool)

Boolean: #t\r\n or #f\r\n



Double(f64)

Double: ,1.23\r\n



BigNumber(String)

Big number: (3492890328409238509324850943850943825024385\r\n



BlobError(String)

Blob error: !21\r\nSYNTAX invalid syntax\r\n



VerbatimString

Verbatim string: =15\r\ntxt:Some string\r\n

Fields

encoding: String

The encoding type (e.g., “txt”, “mkd”)

data: String

The actual string data



Map(HashMap<String, Self>)

Map: %2\r\n+first\r\n:1\r\n+second\r\n:2\r\n



Set(HashSet<Self>)

Set: ~3\r\n+orange\r\n+apple\r\n+one\r\n



Attribute

Attribute: |1\r\n+ttl\r\n:3600\r\n+key\r\n+value\r\n

Fields

attrs: HashMap<String, Self>

The attribute key-value pairs

data: Box<Self>

The actual data with attributes attached



Push(Vec<Self>)

Push: >4\r\n+pubsub\r\n+message\r\n+channel\r\n+hello\r\n

Implementations

Source

impl Resp3Value

pub fn as_string(&self) -> RedisResult<String>

Convert to a string if possible

Errors

Returns an error if the value cannot be converted to a string.

pub fn as_int(&self) -> RedisResult<i64>

Convert to an integer if possible

Errors

Returns an error if the value cannot be converted to an integer.

pub fn as_float(&self) -> RedisResult<f64>

Convert to a float if possible

Errors

Returns an error if the value cannot be converted to a float.

pub fn as_bool(&self) -> RedisResult<bool>

Convert to a boolean if possible

Errors

Returns an error if the value cannot be converted to a boolean.

pub const fn is_null(&self) -> bool

Check if the value is null

pub const fn type_name(&self) -> &'static str

Get the type name of the value