pub struct TransactionResult { /* private fields */ }Expand description
Transaction result wrapper for easier handling
Implementations
Sourceimpl TransactionResult
impl TransactionResult
Sourcepub fn next<T>(&mut self) -> RedisResult<T>
pub fn next<T>(&mut self) -> RedisResult<T>
Get the next result from the transaction
Errors
Returns an error if there are no more results or type conversion fails.
Sourcepub fn get<T>(&self, index: usize) -> RedisResult<T>
pub fn get<T>(&self, index: usize) -> RedisResult<T>
Get a result at a specific index
Errors
Returns an error if the index is out of bounds or type conversion fails.
Sourcepub fn into_results(self) -> Vec<RespValue>
pub fn into_results(self) -> Vec<RespValue>
Get all results as a vector